dispMUA.arDispMUAAllocation["z"] =
{
  "zercom online mailer" : [ "zercom.png" ] ,
  "zope/securemailhost" : [ "zope.png" , "http://www.zope.com/" ] ,
  "zen cart mailer" : [ "zen-cart_com.png" , "http://www.zen-cart.com/" ] ,
  "zonepro france" : [ "zonepro.png" , "http://www.zonepro.fr/" ] ,
  "zoznam mailer" : [ "zoznam.png" , "http://www.zoznam.sk/" ] ,
  "zopemailboxer" : [ "zope.png" , "http://www.zope.com/" ] ,
  "zedat-webmail" : [ "zedat.png" , "http://www.zedat.fu-berlin.de/" ] ,
  "zatz zenpress" : [ "zatz-zenpress.png" , "http://zatzhq.zatz.com/zenpress" ] ,
  "zen mailer" : [ "zenmailer.png" , "http://www.zen-e-solutions.com/product4.htm" ] ,
  "zuckmail" : [ "zuckmail.png" , "http://www.facebook.com/press/info.php?execbios" ] ,
  "z-mailer" : [ "z-mailer.png" , "http://www.z57.com/" ] ,
  "zmailer" : [ "zmailer.png" , "http://www.zmailer.org/" ] ,
  "zimbra" : [ "zimbra.png" , "http://www.zimbra.com/" ] ,
  "zimacs" : [ "zimacs.png" , "http://zimacs.zetnet.co.uk/" ] ,
  "zarafa" : [ "zarafa.png" , "http://www.zarafaserver.de/" ] ,
  "z-mail" : [ "z-mail.png" , "http://www.well.com/user/barts/mush.html" ] ,
  "zmail" : [ "zmail.png" , "http://zsentry.com/ZMAIL.htm" ] ,
}
